@@ -4,7 +4,7 @@
 #
 # timsieved client script
 #
-# Copyright © 2006-2009 Phil Pennock.  All rights reserved.
+# Copyright © 2006-2010 Phil Pennock.  All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -33,6 +33,7 @@
 use warnings;
 use strict;
 
+# These are the defaults, some may be overriden on the command-line.
 my %ssl_options = (
 	SSL_version	=> 'TLSv1',
 	SSL_cipher_list	=> 'ALL:!aNULL:!NULL:!LOW:!EXP:!ADH:@STRENGTH',
@@ -48,7 +49,7 @@ my @cmd_localfs_ls = qw( ls -C );
 # No user-serviceable parts below
 
 our $VERSION = 0;
-my $svn_revision = '$Revision: 69 $';
+my $svn_revision = '$Revision: 72 $';
 if ($svn_revision =~ /^.Revision:\s*(\d+)\s*\$\z/) {
 	$svn_revision = $1;
 	$VERSION = '0.' . $1;
@@ -68,6 +69,7 @@ use Authen::SASL::Perl::EXTERNAL; # We munge inside its private stuff.
 use Cwd qw();
 use Errno;
 use File::Basename qw();
+use File::Spec;
 use Getopt::Long;
 use IO::File;
 use IO::Socket::INET6;
@@ -147,6 +149,7 @@ GetOptions(
 	"clientkey=s"	=> \$sslkeyfile,
 	"clientcert=s"	=> \$sslcertfile,
 	"clientkeycert=s" => sub { $sslkeyfile = $sslcertfile = $_[1] },
+	"notlsverify|nosslverify" => sub { $ssl_options{'SSL_verify_mode'} = 0x00 },
 	"noclearauth"	=> \$forbid_clearauth,
 	"noclearchan"	=> sub { $forbid_clearauth = $forbid_clearchan = 1 },
 	"4"		=> sub { $net_domain = AF_INET },
@@ -806,6 +809,23 @@ my %subst_patterns = (
 	RAND16		=> sub { return '' . int rand 65535 },
 );
 
+# ######################################################################
+# Fix-up for optional stuff, where missing modules disable functionality.
+
+my $have_needed_man_mods;
+BEGIN {
+	eval {
+		my $mod = 'Pod::Simple::Text';
+		my $mp = File::Spec->catfile(split(/::/, $mod));
+		require "$mp.pm";
+		import Pod::Simple::Text;
+		$have_needed_man_mods = 1;
+	};
+}
+unless ($have_needed_man_mods) {
+	delete $sieve_commands{'man'};
+}
+
 # ######################################################################
 # Do something
 
@@ -1212,16 +1232,19 @@ sub aux_help
 		print "\n";
 		if (exists $aliases{$c}) {
 			print $indentspace, 'aka: ',
-				join(' ', @{$aliases{$c}}), "\n";
+				join(' ', sort @{$aliases{$c}}), "\n";
 		}
 	}
 }
 
 sub aux_man
 {
-	use Pod::Text;
+	unless ($have_needed_man_mods) {
+		print STDERR "Sorry, you're missing modules we need\n";
+		return;
+	}
 	seek DATA, $DATASTART, 0;
-	my $parser = Pod::Text->new();
+	my $parser = Pod::Simple::Text->new();
 	$parser->no_whining(1);
 	$parser->output_fh(*STDOUT);
 	$parser->parse_file(*DATA);
@@ -1489,8 +1512,8 @@ sieve-connect - managesieve command-line client
                [--server <hostname>] [--port <portspec>] [--4|--6]
 	       [--user <authentication_id>] [--authzid <authzid>]
 	       [--realm <realm>] [--passwordfd <n>]
-	       [--clientkey <file> --clientcert <file>]|
-	        [--clientkeycert <file>]
+	       [--clientkey <file> --clientcert <file>]|[--clientkeycert <file>]
+	       [--notlsverify|--nosslverify]
 	       [--noclearauth] [--noclearchan]
 	       [--authmech <mechanism>]
 	       [--upload|--download|--list|--delete|
@@ -1562,6 +1585,11 @@ Everything until the newline before EOF is the password,
 so it can contain embedded newlines.  Do not provide passwords on a
 command-line or in a process environment.
 
+If you are willing to accept the risk of man-in-the-middle active attacks
+and you are unable to arrange for the relevant Certificate Authority
+certificate to be available, then you can lower your safety with the
+B<--notlsverify> option, also spelt B<--nosslverify>.
+
 For SSL client certificate authentication, either B<--clientkeycert> may
 be used to refer to a file with both the key and cert present or both
 B<--clientkey> and B<--clientcert> should point to the relevant files.
@@ -1627,6 +1655,7 @@ Phil Pennock E<lt>phil-perl@spodhuis.orgE<gt> is guilty, m'Lud.
 
 Perl.  F<Authen::SASL>.  F<IO::Socket::INET6>.
 F<IO::Socket::SSL> (at least version 0.97).  F<Pod::Usage>.
+F<Pod::Simple::Text> for built-in man command (optional).
 F<Term::ReadKey> to get passwords without echo.
 Various other Perl modules which are believed to be standard.
 F<Term::ReadLine> will significantly improve interactive mode.
